pub struct EdnsFlags {
pub dnssec_ok: bool,
pub z: u16,
}Expand description
Fields
dnssec_ok: boolDNSSEC OK bit as defined by RFC 3225
z: u16Remaining bits in the flags field
Note that the most significant bit in this value is represented by the dnssec_ok field.
As such, it will be zero when decoding and will not be encoded.
Unless you have a specific need to set this value, we recommend leaving this as zero.